@@ -2,8 +2,6 @@
 Adds several fields which are helpful for SEO optimization
 """
 
-import logging
-
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
@@ -17,8 +15,7 @@ def register(cls, admin_cls):
         admin_cls.search_fields += ('meta_keywords', 'meta_description')
 
         if admin_cls.fieldsets:
-            fieldsets = [ f for f in admin_cls.fieldsets if f[0] == _('Other options')]
-            if fieldsets:
-                fieldsets[0][1]['fields'].extend(['meta_keywords', 'meta_description'])
-            else:
-                logging.warning("Couldn't determine which fieldset on %s should have the seo fields", admin_cls)
+            admin_cls.fieldsets.append((_('Search engine optimization'), {
+                    'fields': ('meta_keywords', 'meta_description'),
+                    'classes': ('collapse',),
+                }))
