@@ -11,6 +11,7 @@ from feincms._internal import monkeypatch_property
 
 def register(cls, admin_cls):
     cls.add_to_class('symlinked_page', models.ForeignKey('self', blank=True, null=True,
+        related_name='%(app_label)s_%(class)s_symlinks',
         verbose_name=_('symlinked page'),
         help_text=_('All content is inherited from this page if given.')))
 
@@ -25,3 +26,8 @@ def register(cls, admin_cls):
         return self._content_proxy
 
     admin_cls.raw_id_fields.append('symlinked_page')
+
+    admin_cls.fieldsets.append((_('Symlinked page'), {
+        'fields': ('symlinked_page',),
+        'classes': ('collapse',),
+        }))
