@@ -151,7 +151,8 @@ def Translation(model):
     class Inner(models.Model):
         parent = models.ForeignKey(model, related_name='translations')
         language_code = models.CharField(_('language'), max_length=10,
-		choices=settings.LANGUAGES, default=settings.LANGUAGES[0][0])
+                choices=settings.LANGUAGES, default=settings.LANGUAGES[0][0],
+                editable=len(settings.LANGUAGES) > 1)
 
         class Meta:
             abstract = True
@@ -164,12 +165,6 @@ def Translation(model):
 
             self.parent.purge_translation_cache()
 
-        def save(self, *args, **kwargs):
-            super(Inner, self).save(*args, **kwargs)
-
-            self.parent.purge_translation_cache()
-
-
     return Inner
 
 
